<?php
/**
 * Custom functions that act independently of the theme templates
 * Eventually, some of the functionality here could be replaced by core features
 */

/**
 * Adds custom classes to the array of body classes.
 */
function creatively_body_classes( $classes ) {

	// Adds a class of multi-author to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'multi-author';
	}

	// Adds a class if a post or page has featured image.
	if ( has_post_thumbnail() ) {
		$classes[] = 'has-featured-image';
	}

	if ( is_singular() ) {

		// Adds a class for Full width and Grid template.
		if ( is_page_template( 'page-templates/full-width.php' ) || is_page_template( 'page-templates/grid-page.php' ) ) {
			$classes[] = 'full-width-page';
		}

		// Adds a class for Full width narrow template.
		if ( is_page_template( 'page-templates/full-width-narrow.php' ) ) {
			$classes[] = 'full-width-narrow-page';
		}

		// Adds a class for Sidebar Left template.
		if ( is_page_template( 'page-templates/left-sidebar.php' ) ) {
			$classes[] = 'sidebar-left';
		}

	}

	// Adds a class for Blog Full Width template.
	if ( is_page_template( 'page-templates/blog-full-width.php' ) ||
		is_page_template( 'page-templates/blog-grid.php' ) ||
		is_page_template( 'page-templates/blog-grid-2col.php' ) ||
		is_page_template( 'page-templates/blog-masonry.php' ) ||
		is_page_template( 'page-templates/home-masonry.php' ) ||
		is_page_template( 'page-templates/home-masonry-2col.php' ) ||
		is_page_template( 'page-templates/home-masonry-alt.php' ) ||
		is_singular( 'jetpack-portfolio' ) ||
		is_post_type_archive( 'jetpack-portfolio' ) ||
		is_page_template( 'page-templates/portfolio-2col.php' ) ||
		is_page_template( 'page-templates/portfolio-no-gutter.php' ) ||
		is_page_template( 'page-templates/portfolio-2col-alt.php' ) ||
		is_page_template( 'page-templates/portfolio-3col-alt.php' ) ||
		is_page_template( 'page-templates/empty.php' ) ) {
		$classes[] = 'full-width-page';
	}

	// Adds a class for Blog Full Width Narrow template.
	if ( is_page_template( 'page-templates/blog-full-width-narrow.php' ) ) {
		$classes[] = 'full-width-narrow-page';
	}

	// Adds a class for Sidebar Left template.
	if ( is_page_template( 'page-templates/blog-left-sidebar.php' ) ) {
		$classes[] = 'sidebar-left';
	}

	// Adds a class for the Header style
	$header_style = get_theme_mod( 'creatively_header_style', 'left' );
	if ( $header_style === 'left' ) {
		$classes[] = 'logo-left';
	} elseif ( $header_style === 'center' ) {
		$classes[] = 'logo-center';
	} else {
		$classes[] = 'logo-right';
	}

	return $classes;
}
add_filter( 'body_class', 'creatively_body_classes' );

/**
 * Adds custom classes to the array of post classes.
 */
function creatively_post_classes( $classes ) {

	// Adds a class if a post hasn't a thumbnail.
	if ( ! has_post_thumbnail() ) {
		$classes[] = 'no-post-thumbnail';
	}

	// Replace hentry class with entry.
	$classes[] = 'entry';

	return $classes;
}
add_filter( 'post_class', 'creatively_post_classes' );

/**
 * Remove 'hentry' from post_class()
 */
function creatively_remove_hentry( $class ) {
	$class = array_diff( $class, array( 'hentry' ) );
	return $class;
}
add_filter( 'post_class', 'creatively_remove_hentry' );

/**
 * Change the excerpt more string.
 */
function creatively_excerpt_more( $more ) {
	return '&hellip;';
}
add_filter( 'excerpt_more', 'creatively_excerpt_more' );

/**
 * Register custom contact info fields.
 */
function creatively_contact_info_fields( $contactmethods ) {
	$contactmethods['twitter']     = esc_html__( 'Twitter URL', 'creatively' );
	$contactmethods['facebook']    = esc_html__( 'Facebook URL', 'creatively' );
	$contactmethods['gplus']       = esc_html__( 'Google Plus URL', 'creatively' );
	$contactmethods['instagram']   = esc_html__( 'Instagram URL', 'creatively' );
	$contactmethods['pinterest']   = esc_html__( 'Pinterest URL', 'creatively' );
	$contactmethods['linkedin']    = esc_html__( 'Linkedin URL', 'creatively' );

	// Remove default contacts
	unset( $contactmethods['aim'] );
	unset( $contactmethods['jabber'] );
	unset( $contactmethods['yim'] );

	return $contactmethods;
}
add_filter( 'user_contactmethods', 'creatively_contact_info_fields' );

/**
 * Extend archive title
 */
function creatively_extend_archive_title( $title ) {
	if ( is_category() ) {
		$title = single_cat_title( '', false );
	} elseif ( is_tag() ) {
		$title = single_tag_title( '', false );
	} elseif ( is_author() ) {
		$title = get_the_author();
	} elseif ( is_home() && !is_front_page() ) {
		$id = get_option( 'page_for_posts' ); // Get the ID
		$title = get_the_title( $id );
	} elseif ( is_post_type_archive( 'jetpack-portfolio' ) ) {
		$title = esc_html__( 'Projects','creatively' );
	}
	return $title;
}
add_filter( 'get_the_archive_title', 'creatively_extend_archive_title' );

/**
 * Customize tag cloud widget
 */
function creatively_customize_tag_cloud( $args ) {
	$args['largest']  = 13;
	$args['smallest'] = 13;
	$args['unit']     = 'px';
	$args['number']   = 20;
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'creatively_customize_tag_cloud' );

function portfolio_posts_per_page( $query ) {
	$limit = get_option( 'jetpack_portfolio_posts_per_page' );

	if ( ! is_admin() ) {
		if ( $query->is_main_query() && $query->is_post_type_archive( 'jetpack-portfolio' ) ) {
			$q->set( 'posts_per_page', $limit );
		}
	}
}
